/******************************************************************************
 *
 *  Project:        FPS3010 Interface
 *
 *  Filename:       fps3010.h
 *
 *  Purpose:        Control Protocol Constants for FPS3010
 *
 *  Author:         NHands GmbH & Co KG
 */
/*****************************************************************************/
/** @file fps3010.h
 *  @brief Control Protocol Constants for FPS3010
 *
 *  Product specific extension of the generic ncore interface.
 *  Defines constants to be used as parameters or parameter limits
 *  for the control protocol of ucprotocol.h .
 */
/******************************************************************************/
/* $Id: fps3010.h,v 1.2 2012/10/26 12:23:20 trurl Exp $ */

#ifndef __FPS3010_H
#define __FPS3010_H


/** @brief Maximum number of axes
 *
 *  In telegrams where an index field is used to select an axis
 *  the index must be in the range of 0 ... FPS_AXIS_COUNT-1 .
 */
#define FPS_AXIS_COUNT         0x03


/** @brief Single position, low resolution
 *
 *  Read the position of a single axis.
 *  The axis is selected by the index field of the telegram.
 *  The answer will be a single Int32 item that contains the
 *  position in units of 100pm.
 */
#define ID_FP_CHAN_POSITION   0x0688


/** @brief Synchronized positions, high resolution
 *
 *  Read the position of all three axes measured at the same time.
 *  The index field must be 0.
 *  The answer will be a telegram of six data elements with the
 *  following meaning:
 *
 *  @c data[0]: lower 32 bit of position 1 \n
 *  @c data[1]: upper 16 bit of position 1 \n
 *  @c data[2]: lower 32 bit of position 2 \n
 *  @c data[3]: upper 16 bit of position 2 \n
 *  @c data[4]: lower 32 bit of position 3 \n
 *  @c data[5]: upper 16 bit of position 3 \n
 *
 *  The three positions come in units of 1 pm.
 */
#define ID_FPS_SYNC_POS       0x0692



#endif
